#!/bin/bash

###########################
# PSXC-IMDB PRE-ADDON v0.5
# ------------------------
#
# This little bugger will add pre-support for my imdb-script.
# Since there are so many different prescripts, it's rather impossible to
# make one that works with all. However, I've tried to make this as generic
# as possible. The only thing required is the path to the pre'd release.
#
# The script can be run in one of several ways - as a cscript in glftpd, or
# from the prescript itself, or from crontab, or from the bot. Please see
# the README for instructions.

##########
# CONFIG #

# The chrootpath of glftpd. In this script it is only used if the script is
# *not* run chrooted. Depending on how your prescript log stuff, set this to
# glftpd's chroot if this script is running outside chroot, or "" if running.
# inside.
GLROOT=/glftpd
#GLROOT=""

# Path variable. All commands should be within glftpd's bin directory. No need
# to change.
PATH=$GLROOT/bin

# Path to the logfile to read. This normally is glftpd.log, but can be a
# separate file if your prescript logs elsewhere. Please see PRETRIGGER and
# WORD as well.
GLLOG=$GLROOT/ftp-data/logs/glftpd.log
#GLLOG=$GLROOT/ftp-data/logs/prelog

# Location of IMDBLOG (same as in psxc-imdb.sh)
IMDBLOG=$GLROOT/ftp-data/logs/psxc-imdb.log

# Trigger your prescript uses. If you use a separate logfile which do not have
# a trigger (like a prelog or something) set this to "".
PRETRIGGER="PRE:"
#PRETRIGGER="DONE:"
#PRETRIGGER=""

# This is a wordcount read after PRETRIGGER where the path is located. Imagine
# the following as something found in glftpd.log:
#
# Sat Apr 19 06:46:26 2003 PRE: "/site/divx/somedir" "pregroup" "some text"
#
# If PRETRIGGER is "PRE:" then you'd want to set WORDS to "1", as this is the
# location of the path. If PRETRIGGER is "" then you'd set WORDS to "7", as it
# is the 7th word in the line. Please note that text within '"' is counted as
# one word, ie, there're 9 words in my example, not 10.
#
# NEW FEATURE:
# To support f00-pre and others, you can now enter more than one number,
# separated by a space. With SEPARATOR set to "/" (see below), setting WORDS to
# "4 3" with the following in glftpd.log:
#
# Sat Apr 19 06:46:26 2003 PRE: "user" "group" "some.release" "/site/section"
#
# will give "/site/section/some.release" as the path.

WORDS="1"
#WORDS="4 3"
#WORDS=7

# the separator between words grabbed in WORDS. Use "" to disable.
SEPARATOR="/"
#SEPARATOR=""

# CONFIG DONE #
###############

a="`tail -n 5 $GLLOG | grep "$PRETRIGGER" | tail -n 1`"
DIRNAME=""
for WORD in $WORDS; do
 count=0
 combine=0
 if [ -z "$a" ]; then
  exit 0
 fi
 if [ ! -z "$PRETRIGGER" ]; then
  let WORD=WORD+1
 fi
 for b in $a; do
  if [ -z `echo $b | grep "$PRETRIGGER"` ] && [ $count -gt 0 ] || [ -z "$PRETRIGGER" ]; then
   if [ $combine -eq 1 ]; then
    c=$c$b
   else
    c=$b
   fi
   if [ ! -z `echo "$c" | grep "^\""` ]; then
    combine=1
   else
    c=$b
    let count=count+1
   fi
   if [ ! -z `echo "$c" | grep "\"$"` ]; then
    combine=0
    let count=count+1
   fi
   if [ $count -eq $WORD ]; then
    break
   fi
  else
   if [ "$b" = "$PRETRIGGER" ]; then
    count=1
   fi
  fi
 done
 DIRNAME="$DIRNAME""$c"
done
DIRNAME=`echo $DIRNAME | sed "s|\"\"|$SEPARATOR|g" | sed "s|\"||g"`
if [ -d $GLROOT$DIRNAME ]; then
 FILENAME=`ls -1 $GLROOT$DIRNAME | grep "\.[Nn][Ff][Oo]$" | head -1`
 IMDBURL="`grep [Ii][Mm][Dd][Bb] $GLROOT$DIRNAME/$FILENAME | tr ' ' '\n' | sed -n /[hH][tT][tT][pP]:[/][/].*[.][iI][mM][dD][bB].*[?].[0-9]/p | head -n 1 | tr -c 'a-zA-Z0-9:./?' ' ' | sed "s/ //g"`"
 if [ ! -z "`echo $IMDBURL | grep "\.imdb\."`" ]; then
  IMDBURL="http://us.imdb.com/Title?""`echo $IMDBURL | sed "s/=/-/g" | sed "s/.imdb./=/" | cut -d "=" -f 2 | cut -d "?" -f 2 | cut -b 1-7 | tr -c '0-9' ' ' | sed "s/ //g"`"
 fi
 if [ ! -z "$IMDBURL" ]; then
  echo "$IMDBURL""|""$DIRNAME" >> $IMDBLOG
 fi
fi
exit 0

