#!/bin/bash

# PSXC IMDB INFO v1.2 #
#######################

#######
#CONFIG

### Global settings. Unless you use a somewhat modified version of     ###
### glftpd, these variables will be okay with little or no             ###
### modification.                                                      ###

# version number. do not change.
VERSION="v1.2f"

# debug. only set this to on if nothing happens when script is run. and
# only run this in interactive mode. two variables will be printed over
# and over, and the tmp-output will not be removed. only really useful
# if you send the output and the content of the tmp-file to the author,
# along with some info on your system (kernel, distro etc)
DEBUG=""
#DEBUG="ON"

# this path is usually sufficient for chrooted env. - no need to change.
PATHCHROOTED="/bin"

# PATH variable. Make sure you have all needed executables.
PATH=$GLROOT/bin:/bin:/usr/bin:/usr/local/bin:/sbin:/usr/sbin:/usr/local/sbin

# your glftpd root path.
GLROOT=/glftpd

# logfile used - chrooted version. This file logs dirname and imdb-url.
IMDBLOGCHROOTED=/ftp-data/logs/psxc-imdb.log

# path to logfile for imdb lookups. Same as above (IMDBLOGCHROOTED), just
# with the path outside glftpd's chrooted environment. Should not be changed.
IMDBLOG=$GLROOT$IMDBLOGCHROOTED

# path to a logfile which keeps a specified number of IMDb urls.
# this is used to prevent the bot from showing IMDB info again and
# again for the same file.
IMDBURLLOG=$GLROOT$IMDBLOGCHROOTED.keep

# the number of IMDB urls to keep in the logfile (above). This will prevent
# duplicate imdb outputs if the same movie is uploaded more than once.
KEEPURLS=20
#KEEPURLS=1

# location of the file data for the bot is parsed to, normally glftpd.log.
# you might want to change this if normal output doesn't work, or changing
# the TRIGGER won't help, or writing to glftpd.log isn't possible.
# Remember to use psxc-imdb-full.tcl if you use something other than the
# glftpd.log. Read README for more info.
GLLOG=$GLROOT/ftp-data/logs/glftpd.log
#GLLOG=$GLROOT/ftp-data/logs/psxc-moviedata.log

# a temp file used to fetch imdb info.
TMPFILE=$GLROOT/ftp-data/logs/psxc-imdb.tmp

# bold character used for bot. Use "" to disable.
BOLD=""

# quote char used. Since tcl and bash freaks out on a few chars, the
# script replaces these with the following. Currently, only " is replaced
# Do not use " or ` or some other special char here!
QUOTECHAR="'"
#QUOTECHAR="_"

# should the script look up business data for the opening weekend on the
# movie? use "" to disable.
USEBUSINESS="YES"
#USEBUSINESS=""

# Show premiere date? Will show date of first public showing/premiere of the
# movie. Premiere date takes precedence over public showing like Cannes etc.
USEPREMIERE="YES"
#USEPREMIERE=""

# Show limited date? Will show first date of limited showing.
USELIMITED="YES"
#USELIMITED=""

# Lynx retries
LYNXTRIES=3

### The following will affect output of the script. First the variables ###
### for the bot output.                                                 ###

# should the script write to glftpd.log (ie, bot support)? Use "" to
# disable.
USEBOT="YES"
#USEBOT=""

# Trigger for bot. Most bots should be able to show the info with the UPDATE
# trigger. If you like to modify your bot for special purposes, edit to
# whatever catches your fancy/setup.
# Please BE SURE YOU KNOW WHAT YOU ARE DOING before changing this. Just putting
# it to something that catches the mood will prevent any output in the channel.
TRIGGER="UPDATE:"
#TRIGGER="IMDB:"

# Date format used by bot. Edit according to your OS (FBSD/Linux is default)
DATE=`date +"%a %b %d %H:%M:%S %Y"`

# To prevent output in channel when movies are uploaded in private/affill/group-
# dirs, put the dirs here. Dirs are separated by a space."
BOTEXEMPT="/site/GROUPS /site/AFFILS /site/PRIVATE /site/TMP"

# The following wil output only ONE LINE OF INFO to the bot. This overrides the
# rest of the settings, except BOTHEAD. The line includes Title, Country, Genre,
# Rating and IMDb URL. Use "" for normal output.
BOTONELINE=""
#BOTONELINE="YES"

# This line will be written prior to whatever IMDB info found. Use "" to disable.
# Put RELEASENAME somewhere if you'd like to announce the name of the release.
#BOTHEAD="Releasename..: RELEASENAME"
#BOTHEAD="IMDb has some interesting facts on RELEASENAME"
BOTHEAD="info on RELEASENAME from IMDb:"
#BOTHEAD=""

# Should the short version of user comments be shown in channel? "" disables
SHOWCOMMENTSHORT="YES"
#SHOWCOMMENTSHORT=""

# Showing both Tagline and Plot Outline may be too much to your liking. This variable
# will show either Tagline or Plot Outline if either or both are found. Use "TAG" if
# you prefer Tagline over Plot Outline, "PLOT" if you prefer Plot Outline over Tagline,
# "NONE" to disable both, or "" to show both.
#TAGPLOT=""      # Show both
#TAGPLOT="TAG"   # Show one, tag prefered
TAGPLOT="PLOT"  # Show one, plot prefered
#TAGPLOT="NONE"  # Show none

### The next variables will affect output to a file in the release-dir. The ###
### idea here is to show this file when users enters the dir, thus removing ###
### the need to view the .nfo and looking up info on IMDb themselves. Check ###
### the README for more info.                                               ###

# The file to write imdb info to in the movie dir. Use "" to disable.
DOTIMDB=".imdb"
#DOTIMDB=""

# Someone requested a separate file for just the link, a <releasename>.url
# Use "" to disable (default).
DOTURL=""
#DOTURL="ENABLED"

# Maximum number of cast members listed.
CASTNUM=5 # max number of lines showing Credited Cast
#CASTNUM=99

# Should user comment be shown in DOTIMDB? "" disables. This is in some cases a
# lot of info - feel your way on this one. Default is disabled.
#SHOWCOMMENT="YES"
SHOWCOMMENT=""

# Maximum width for text written to DOTIMDB. This controls how many chars wide the
# text should be before word-wrapping it.
IMDBWIDTH=77

# head and tail written to DOTIMDB. Take notice of IMDBWITH - this should not be
# wider than that. This output will be written as "echo -e" which means you can use
# control characters like \n, thus the head and tail can stretch over 1 or more lines.
IMDBHEAD="============================ PSXC IMDB INFO $VERSION ============================\n"
IMDBTAIL="\n============================ PSXC IMDB INFO $VERSION ============================"

### The following is a BETA feature, and has really nothing to do with IMDb info ###
### at all. It's a quick and dirty way to extract release dates from the .nfo    ###
### files, and putting that info in a separate file. It works like the .imdb     ###
### file (above) and is supposed to be listed on entering the dir.               ###

# Use the beta date-extraction? Enter a name here, or "" to disable.
DOTDATE=".date"
#DOTDATE=""

# END OF CONFIG
##########################################################################################

if [ ! -z $1 ]; then

#### CHROOTED PART #####
 PATH=$PATHCHROOTED
 IMDBLOG=$IMDBLOGCHROOTED
 FILENAME="$@"
 case $FILENAME in
  *.[nN][fF][oO])
   if [ ! -z "$DOTDATE" ]; then
    grep [Dd][Aa][Tt][Ee] $FILENAME | tr -c '/a-zA-Z0-9:. -/\n' ' ' | tr -s ' ' > $DOTDATE
    chmod 644 $DOTDATE
   fi
   IMDBURL="`grep [Ii][Mm][Dd][Bb] $FILENAME | tr ' ' '\n' | sed -n /[hH][tT][tT][pP]:[/][/].*[.][iI][mM][dD][bB].*[?].[0-9]/p | head -n 1 | tr -c 'a-zA-Z0-9:./?' ' ' | sed "s/ //g"`"
   if [ ! -z "`echo $IMDBURL | grep "\.imdb\."`" ]; then
    IMDBURL="http://us.imdb.com/Title?""`echo $IMDBURL | sed "s/=/-/g" | sed "s/.imdb./=/" | cut -d "=" -f 2 | cut -d "?" -f 2 | cut -b 1-7 | tr -c '0-9' ' ' | sed "s/ //g"`"
   fi
   if [ ! -z "$IMDBURL" ]; then
    echo "$IMDBURL""|""$PWD" >> $IMDBLOG
    if [ ! -z "$DOTIMDB" ]; then
     echo -n "" > $DOTIMDB
     chmod 666 $DOTIMDB
    fi
    if [ ! -z "$DOTURL" ]; then
     DOTIMDB="`basename "$PWD" | sed "s/ /./g"`.url"
     echo "[InternetShortcut]" > $DOTIMDB
     echo "URL=""$IMDBURL" > $DOTIMDB
     chmod 644 $DOTIMDB
    fi
   fi
  ;;
 esac
 exit 0

else
##### MAIN PART #####
 if [ ! -e $IMDBLOG ]; then
  echo "Seems like this is the first time the script is run."
  echo "I will try to check/setup everything."
  echo "You are running this script as `whoami`. Please use"
  echo "the same user's crontab when setting this up."
  echo ""
  echo "testing if all needed binaries are present..."
  BINARIES="date cat echo cut lynx grep head sed awk fold rm bash ls basename dirname chmod"
  BINARIESCHROOT="grep tr sed head echo bash chmod basename"
  echo -n "In $GLROOT/bin: "
  for BINAR in $BINARIESCHROOT; do
   test -e $GLROOT/bin/$BINAR || { echo "$BINAR missing. Please fix."; exit 1; };
   echo -n "."
  done
  echo ""
  echo -n "In $PATH: "
  for BINAR in $BINARIES; do
   which $BINAR >/dev/null 2>&1 || { echo "$BINAR missing/not in path. Please fix."; exit 1; };
   echo -n "."
  done
  echo ""
  echo "Initializing the files..."
  test -w $GLLOG || { echo "`whoami` Can not write to \$GLLOG ($GLLOG)"; exit 1; };
  touch $TMPFILE >/dev/null 2>&1 || { echo "ERROR! Could not create \$TMPFILE ($TMPFILE)"; exit 1; };
  chmod 666 $TMPFILE || { echo "could not make $TMPFILE world writable."; exit 1; };
  touch $IMDBURLLOG >/dev/null 2>&1 || { echo "ERROR! Could not create \$IMDBURLLOG ($IMDBURLLOG)"; exit 1; };
  chmod 666 $IMDBURLLOG || { echo "could not make $IMDBURLLOG world writable."; exit 1; };
  touch $IMDBLOG >/dev/null 2>&1 || { echo "ERROR! Could not create \$IMDBLOG ($IMDBLOG)"; exit 1; };
  chmod 666 $IMDBLOG || { echo "could not make $IMDBLOG world writable."; exit 1; };
  echo "Done testing. Everything seems to be okay."
  exit 0
 fi
 if [ -z $IMDBLOG ]; then
  exit 0
 fi
 BOTHEADORIG="$BOTHEAD"
 DOTIMDBORIG="$DOTIMDB"
 USEBOTORIG="$USEBOT"
 LYNXTRIESORIG="$LYNXTRIES"
 USEBUSINESSORIG="$USEBUSINESS"
 USEPREMIEREORIG="$USEPREMIERE"
 USELIMITEDORIG="$USELIMITED"
 for IMDBLINE in `cat $IMDBLOG`; do
  BUSINESS=""
  BUSINESSSHORT=""
  PREMIERE=""
  LIMITED=""
  EXEMPTED=""
  BOTHEAD="$BOTHEADORIG"
  DOTIMDB="$DOTIMDBORIG"
  USEBOT="$USEBOTORIG"
  LYNXTRIES="$LYNXTRIESORIG"
  USEBUSINESS="$USEBUSINESSORIG"
  USEPREMIERE="$USEPREMIEREORIG"
  USELIMITED="$USELIMITEDORIG"
  IMDBURL="`echo $IMDBLINE | cut -d "|" -f 1`"
  IMDBLNK="`echo $IMDBLINE | cut -d "|" -f 2`"
  DEBUGCOUNT=1
  if [ ! -z $DEBUG ]; then
   echo "$DEBUGCOUNT : DOTIMDB = '$DOTIMDB'"
   echo "$DEBUGCOUNT : USEBOT = '$USEBOT'"
  fi
  if [ -d $GLROOT$IMDBLNK ]; then
   IMDBDIR="`basename $IMDBLNK`"
   BASELNK="`dirname $IMDBLNK`"
   IMDBLKL="$IMDBLNK"
   IMDBLNK="$GLROOT$IMDBLNK/$DOTIMDB"
  else
   DOTIMDB=""
   USEBOT=""
  fi
  DEBUGCOUNT=2
  if [ ! -z $DEBUG ]; then
   echo "$DEBUGCOUNT : DOTIMDB = '$DOTIMDB'"
   echo "$DEBUGCOUNT : USEBOT = '$USEBOT'"  
  fi
  for EXEMPT in $BOTEXEMPT; do
   if [ ! -z `echo "$BASELNK" | grep "$EXEMPT"` ]; then
    USEBOT=""
    EXEMPTED="ON"
   fi
  done
  DEBUGCOUNT=3
  if [ ! -z $DEBUG ]; then
   echo "$DEBUGCOUNT : DOTIMDB = '$DOTIMDB'"
   echo "$DEBUGCOUNT : USEBOT = '$USEBOT'"  
  fi
  if [ ! -z `cat $IMDBURLLOG | grep $IMDBURL` ] || [ ! -z $EXEMPTED ]; then
   USEBOT=""
  else
   echo $IMDBURL >> $IMDBURLLOG
   tail -n $KEEPURLS $IMDBURLLOG > $TMPFILE
   cat $TMPFILE > $IMDBURLLOG
   echo -n "" > $TMPFILE
  fi
  DEBUGCOUNT=4
  if [ ! -z $DEBUG ]; then
   echo "$DEBUGCOUNT : DOTIMDB = '$DOTIMDB'"
   echo "$DEBUGCOUNT : USEBOT = '$USEBOT'"  
  fi
  while [ $LYNXTRIES -gt 0 ]; do
   lynx -dump -nolist -width=1000 -hiddenlinks=ignore $IMDBURL > $TMPFILE 2>&1 | {
    if [ $? = "0" ]; then
     exit 0
    else
     exit 1
    fi
   }
   if [ $? = "1" ]; then
    let LYNXTRIES=LYNXTRIES-1
    sleep 1
   else
    LYNXTRIES="$LYNXTRIESORIG"
    break
   fi
  done
  if [ "$LYNXTRIES" = "$LYNXTRIESORIG" ]; then
   TITLE=`cat $TMPFILE | grep "^[a-zA-Z0-9\"]" | sed "s/\"//g" | head -1`
   if [ "$TITLE" = "IMDb title search" ] || [ -z "$TITLE" ]; then
    USEBOT=""
    DOTIMDB=""
   else
    GENRE=`cat $TMPFILE | grep "Genre:" | sed "s/(more)//" | sed "s/   //" | sed "s/Genre:/Genre........:/" | sed s/\"/$QUOTECHAR/g | head -1`
    RATING=`cat $TMPFILE | grep "User\ Rating:" | sed "s/   //" | sed "s/ [Vv][Oo][Tt][Ee] [Hh][Ee][Rr][Ee]//" | sed "s/User Rating:/User Rating..:/" | sed "s/* //g" | sed "s/_ //g" | sed s/\"/$QUOTECHAR/g | head -1`
    COUNTRY=`cat $TMPFILE | grep "Country:" | sed "s/   //" | sed "s/Country:/Country......:/" | sed s/\"/$QUOTECHAR/g | head -1`
    ONELINE="`echo "$BOLD$TITLE$BOLD""[$COUNTRY]: $GENRE - $BOLD$RATING$BOLD""- $IMDBURL" | sed "s/Genre........: //" | sed "s/User Rating..: //" | sed "s/Country......: //" | sed "s/  / /g"`"
    TAGLINE=`cat $TMPFILE | grep "Tagline:" | sed "s/(more)//" | sed "s/   //" | sed "s/([Mm][Oo][Rr][Ee])//" | sed "s/Tagline:/Tagline......:/" | sed s/\"/$QUOTECHAR/g | head -1`
    LANGUAGE=`cat $TMPFILE | grep "Language:" | sed "s/   //" | sed "s/Language:/Language.....:/" | sed s/\"/$QUOTECHAR/g | head -1`
    PLOT=`cat $TMPFILE | grep "Plot\ [OS][u][tm][lm][ia][nr][ey]:" | sed "s/   //" | sed "s/ ([Vv][Ii][Ee][Ww] [Tt][Rr][Aa][Ii][Ll][Ee][Rr])//" | sed "s/([Mm][Oo][Rr][Ee])//" | sed "s/Plot [OS][u][tm][lm][ia][nr][ey][:]/Plot Outline.:/" | sed s/\"/$QUOTECHAR/g | head -1`
    CERT=`cat $TMPFILE | grep "Certification:" | sed "s/   //" | sed s/\"/$QUOTECHAR/g | head -1`
    CAST=`cat $TMPFILE | grep "\ \.\.\.\.\ " | sed s/\"/$QUOTECHAR/g | head -$CASTNUM`
    COMMENTSHORT=`cat $TMPFILE | grep "User Comments:" | head -1 | sed "s/   //" | sed "s/([Mm][Oo][Rr][Ee])//" | sed s/\"/$QUOTECHAR/g`
    COMMENT=`cat $TMPFILE | awk '/User Comments:$/, /Check for other user comments.$/' | sed s/\"/$QUOTECHAR/g`
    RUNTIME=`cat $TMPFILE | grep "Runtime:" |  sed "s/   //" | sed "s/Runtime:/Runtime......:/" | sed s/\"/$QUOTECHAR/g | head -1`
    DIRECTOR=`cat $TMPFILE | awk '/Directed by$/, /Writing credits$/' | grep -v "Directed by" | grep -v "Writing Credits" | sed "s/   //" | head -1 | sed s/\"/$QUOTECHAR/g`
    BUSINESSURL=`echo $IMDBURL | sed "s/Title/Business/"`
    RELEASEURL=`echo $IMDBURL | sed "s/Title/ReleaseDates/"`
    while [ $LYNXTRIES -gt 0 ]; do
     lynx -dump $IMDBURL > $TMPFILE 2>&1 | {
      if [ $? = "0" ]; then
       exit 0
      else
       exit 1
      fi
     }
     if [ $? = "1" ]; then
      let LYNXTRIES=LYNXTRIES-1
      sleep 1
     else
      LYNXTRIES="$LYNXTRIESORIG"
      break
     fi      
    done   
    if [ -z "`cat $TMPFILE | grep -F "$BUSINESSURL"`" ]; then
     USEBUSINESS=""
    fi
    if [ -z "`cat $TMPFILE | grep -F "$RELEASEURL"`" ]; then
     USEPREMIERE=""
     USELIMITED=""
    fi
    if [ ! -z "$USEBUSINESS" ]; then
     while [ $LYNXTRIES -gt 0 ]; do
      lynx -dump -nolist -width=1000 -hiddenlinks=ignore $BUSINESSURL > $TMPFILE 2>&1 | {
       if [ $? = "0" ]; then
        exit 0
       else
        exit 1
       fi
      }
      if [ $? = "1" ]; then
       let LYNXTRIES=LYNXTRIES-1
       sleep 1
      else
       LYNXTRIES="$LYNXTRIESORIG"
       break
      fi
     done
     if [ "$LYNXTRIES" = "$LYNXTRIESORIG" ]; then
      BUSINESS=`cat $TMPFILE  | awk '/Opening Weekend$/,/Gross$/' | grep "(" | sed "s/       //" | sed s/\"/$QUOTECHAR/g`
      BUSINESSSHORT=`cat $TMPFILE | awk '/Opening Weekend$/,/Gross$/' | grep "screens" | grep "USA" | sed "s/          //" | sed s/\"/$QUOTECHAR/g | head -1`
     fi
    fi
    if [ ! -z "$USEPREMIERE" ] || [ ! -z "$USELIMITED" ]; then
     while [ $LYNXTRIES -gt 0 ]; do
      lynx -dump -nolist -width=1000 -hiddenlinks=ignore $RELEASEURL > $TMPFILE 2>&1 | {
       if [ $? = "0" ]; then
        exit 0
       else
        exit 1
       fi
      }
      if [ $? = "1" ]; then
       let LYNXTRIES=LYNXTRIES-1
       sleep 1
      else
       LYNXTRIES="$LYNXTRIESORIG"
       break
      fi
     done
     if [ "$LYNXTRIES" = "$LYNXTRIESORIG" ]; then
      if [ ! -z "$USEPREMIERE" ]; then
       PREMIERE=`cat $TMPFILE | awk /Date$/,/endofThefile/ | grep "(" | grep "[Pp][Rr][Ee][Mm][Ii][Ee][Rr][Ee]" | head -n 1 | sed "s/   //" | sed "s/  / /g" | sed "s/  / /g" | sed "s/  / /g" | sed "s/  / /g" | sed s/\"/$QUOTECHAR/g`
       if [ -z "$PREMIERE" ]; then
        PREMIERE=`cat $TMPFILE | awk /Date$/,/endofThefile/ | grep -v "Date$" | head -n 1 | sed "s/   //" | sed "s/  / /g" | sed "s/  / /g" | sed "s/  / /g" | sed "s/  / /g" | sed s/\"/$QUOTECHAR/g`
       fi
      fi
      if [ ! -z "$USELIMITED" ]; then
       LIMITED=`cat $TMPFILE | awk /Date$/,/endofThefile/ | grep "(" | grep "[Ll][Ii][Mm][Ii][Tt][Ee][Dd]" | head -n 1 | sed "s/   //" | sed "s/  / /g" | sed "s/  / /g" | sed "s/  / /g" | sed "s/  / /g" | sed s/\"/$QUOTECHAR/g`
       if [ "$PREMIERE" = "$LIMITED" ]; then
        PREMIERE=""
       fi
      fi
     fi
    fi
    if [ ! -z "$IMDBHEAD" ]; then
     BOTHEAD=`echo $BOTHEADORIG | sed s/RELEASENAME/$BOLD$IMDBDIR$BOLD/`
    fi
    if [ ! -z $DEBUG ]; then
     DEBUGCOUNT=5
     echo "$DEBUGCOUNT : DOTIMDB = '$DOTIMDB'"
     echo "$DEBUGCOUNT : USEBOT = '$USEBOT'"  
    fi
    if [ ! -z "$DIRECTOR" ]; then
     DIRECTOR="Directed by..: $DIRECTOR"
    fi
   fi
   if [ ! -z $DEBUG ]; then
    DEBUGCOUNT=6
    echo "$DEBUGCOUNT : DOTIMDB = '$DOTIMDB'"
    echo "$DEBUGCOUNT : USEBOT = '$USEBOT'"  
   fi
   if [ ! -z "$USEBOT" ]; then
    HEADTMP="Title........: $BOLD$TITLE$BOLD"
    if [ ! -z "$COUNTRY" ]; then
     HEADTMP="$HEADTMP / $COUNTRY"
    fi
    if [ ! -z "$LANGUAGE" ]; then
     HEADTMP="$HEADTMP / $BOLD$LANGUAGE$BOLD"
    fi
    HEAD=`echo "$HEADTMP" | sed "s/Country......: //" | sed "s/Language.....: //"`
    if [ ! -z "$BOTHEAD" ]; then
     echo "$DATE $TRIGGER \"$IMDBLKL\" \"$BOTHEAD\"" >> $GLLOG
    fi
    if [ ! -z "$HEAD" ] && [ -z "$BOTONELINE" ]; then
     echo "$DATE $TRIGGER \"$IMDBLKL\" \"$HEAD\"" >> $GLLOG
    fi
    if [ -z "$BOTONELINE" ]; then
     echo "$DATE $TRIGGER \"$IMDBLKL\" \"IMDb Link....: $IMDBURL\"" >> $GLLOG
    fi
    if [ ! -z "$DIRECTOR" ] && [ -z "$BOTONELINE" ]; then
     echo "$DATE $TRIGGER \"$IMDBLKL\" \"$DIRECTOR\"" >> $GLLOG
    fi
    if [ ! -z "$GENRE" ] && [ -z "$BOTONELINE" ]; then
     echo "$DATE $TRIGGER \"$IMDBLKL\" \"$GENRE\"" >> $GLLOG
    fi
    if [ ! -z "$RATING" ] && [ -z "$BOTONELINE" ]; then
     echo "$DATE $TRIGGER \"$IMDBLKL\" \"$RATING\"" >> $GLLOG
    fi
    if [ ! -z "$RUNTIME" ] && [ -z "$BOTONELINE" ]; then  
     echo "$DATE $TRIGGER \"$IMDBLKL\" \"$RUNTIME\"" >> $GLLOG
    fi
    if [ ! -z "$BUSINESSSHORT" ]; then
     echo "$DATE $TRIGGER \"$IMDBLKL\" \"Opening Stats: $BUSINESSSHORT\"" >> $GLLOG
    fi
    if [ ! -z "$PREMIERE" ]; then
     echo "$DATE $TRIGGER \"$IMDBLKL\" \"Premiere Date: $PREMIERE\"" >> $GLLOG
    fi
    if [ ! -z "$LIMITED" ]; then
     echo "$DATE $TRIGGER \"$IMDBLKL\" \"Limited Date.: $LIMITED\"" >> $GLLOG
    fi
    if [ ! -z "$TAGLINE" ] && [ ! -z "$PLOT" ] && [ -z "$BOTONELINE" ]; then
     if [ "$TAGPLOT" = "TAG" ]; then
      echo "$DATE $TRIGGER \"$IMDBLKL\" \"$TAGLINE\"" >> $GLLOG
     elif [ "$TAGPLOT" = "PLOT" ]; then
      echo "$DATE $TRIGGER \"$IMDBLKL\" \"$PLOT\"" >> $GLLOG
     fi
    elif [ -z "$TAGPLOT" ] && [ -z "$BOTONELINE" ]; then
     echo "$DATE $TRIGGER \"$IMDBLKL\" \"$PLOT\"" >> $GLLOG
     echo "$DATE $TRIGGER \"$IMDBLKL\" \"$TAGLINE\"" >> $GLLOG
    elif [ ! -z "$TAGLINE" ] && [ ! "$TAGPLOT" = "NONE" ] && [ -z "$BOTONELINE" ]; then
     echo "$DATE $TRIGGER \"$IMDBLKL\" \"$TAGLINE\"" >> $GLLOG
    elif [ ! -z "$PLOT" ] && [ ! "$TAGPLOT" = "NONE" ] && [ -z "$BOTONELINE" ]; then
     echo "$DATE $TRIGGER \"$IMDBLKL\" \"$PLOT\"" >> $GLLOG
    fi
    if [ ! -z "$SHOWCOMMENTSHORT" ] && [ ! "$COMMENTSHORT" = "User Comments:" ] && [ -z "$BOTONELINE" ]; then
     echo "$DATE $TRIGGER \"$IMDBLKL\" \"$COMMENTSHORT\"" >> $GLLOG
    fi
    if  [ ! -z "$BOTONELINE" ]; then
     echo "$DATE $TRIGGER \"$IMDBLKL\" \"$ONELINE\"" >> $GLLOG
    fi
   fi
   if [ ! -z "$DOTIMDB" ]; then
    echo -e "$IMDBHEAD" > $IMDBLNK
    OWNER=`ls -1nl $GLROOT$IMDBLKL | tail -1 | { read junk junk owner group junk; echo $owner:$group; };`
    echo "Title........: $TITLE" | fold -s -w $IMDBWIDTH | head -1 >> $IMDBLNK
    echo "-" >> $IMDBLNK
    echo "IMDb Link....: $IMDBURL" | head -1 >> $IMDBLNK
    if [ ! -z "$DIRECTOR" ]; then
     echo "$DIRECTOR" | fold -s -w $IMDBWIDTH | head -1 >> $IMDBLNK
    fi
    if [ ! -z "$GENRE" ]; then
     echo "$GENRE" | fold -s -w $IMDBWIDTH | head -1 >> $IMDBLNK
    fi
    if [ ! -z "$RATING" ]; then
     echo "$RATING" | fold -s -w $IMDBWIDTH | head -1 >> $IMDBLNK
    fi
    if [ ! -z "$TAGLINE" ]; then
     echo "$TAGLINE" | fold -s -w $IMDBWIDTH >> $IMDBLNK
    fi
    echo "-" >> $IMDBLNK
    if [ ! -z "$COUNTRY" ]; then
     echo "$COUNTRY" | fold -s -w $IMDBWIDTH | head -1 >> $IMDBLNK
    fi
    if [ ! -z "$LANGUAGE" ]; then
     echo "$LANGUAGE" | fold -s -w $IMDBWIDTH | head -1 >> $IMDBLNK
    fi
    if [ ! -z "$CERT" ]; then
     echo "$CERT" | fold -s -w $IMDBWIDTH | head -1 >> $IMDBLNK
    fi
    if [ ! -z "$PREMIERE" ]; then         
     echo "Premiere Date: $PREMIERE" | fold -s -w $IMDBWIDTH | head -1 >> $IMDBLNK
    fi
    if [ ! -z "$LIMITED" ]; then      
     echo "Limited Date.: $LIMITED" | fold -s -w $IMDBWIDTH | head -1 >> $IMDBLNK
    fi
    if [ ! -z "$RUNTIME" ]; then
     echo "$RUNTIME" | fold -s -w $IMDBWIDTH | head -1 >> $IMDBLNK
    fi
    if [ ! -z "$CAST" ]; then
     echo "-" >> $IMDBLNK
     echo "Credited Cast:" >> $IMDBLNK
     echo "$CAST" | fold -s -w $IMDBWIDTH >> $IMDBLNK
    fi
    if [ ! -z "$BUSINESS" ]; then
     echo "-" >> $IMDBLNK
     echo "Business Data on Opening Weekend:" >> $IMDBLNK
     echo "$BUSINESS" | fold -s -w $IMDBWIDTH >> $IMDBLNK
    fi
    if [ ! -z "$PLOT" ]; then
     echo "-" >> $IMDBLNK
     echo "$PLOT" | fold -s -w $IMDBWIDTH >> $IMDBLNK
    fi
    if [ ! -z "$SHOWCOMMENT" ] && [ ! -z "`echo $COMMENT | grep "^User Comments:" | grep "Check for other user comments.$"`" ]; then
     echo "---" >> $IMDBLNK
     echo "User Comments:" >> $IMDBLNK
     echo "$COMMENT" | grep "^     " | sed "s/     //g" | fold -s -w $IMDBWIDTH >> $IMDBLNK
    fi
    echo -e "$IMDBTAIL" >> $IMDBLNK
   fi
  fi
 done
 echo -n "" > $IMDBLOG
 if [ -z $DEBUG ]; then
  echo -n "" > $TMPFILE
 fi
 exit 0
fi
exit 0
